function [CoO, allphi, ResDeltaC, ResXi, ResS, ResK, ResLS, ResLW, ResDPhi, ResG] = ...
    AndrzejakEspinosoChaos2023(N,epsilon,alphaX,alphaY,nuX,nuY,bX,bY,TS,CO,EO,T,Deltat,verbose)
% This source code allows you to reproduce the simulations presented in the
% paper:
%
% Andrzejak RG, Espinoso A
% Chimera states in multiplex networks: Chameleon-like across-layer synchronization.
% Chaos 33, 053112 (2023), https://doi.org/10.1063/5.0146550
%
% Please give a reference to this manuscript if you use this source code in
% your publications.
%
% Important: Please read the general comments in AndrzejakEspinosoChaos2023Example.m
%
% Equation numbers given below refer to those in the paper.
%
% INPUT
% N: Number of oscillators in each network. In paper: 50
% epsilon: inter-layer coupling strength. In paper: variable
% alphaX, alphaY: phase-lag parameter driver X and response Y. In paper: variable
% nuX, nuY: natural frequency driver X and response Y. In paper: variable
% bX, bY: kernel broadness driver X and response Y. In paper: bX=bY=18
% Deltat: sampling time for integration. In paper: 0.05
% CO: Coupling onset. In paper: 1000 time units = 20000 samples
% EO: Evaluation onse. In paper: 10000 time units = 200000 samples
% T: interval used for evaluation in Eq. 5. In paper: 100 time units = 2000 samples
% TS: Total samples. In paper: 100000 time units = 2000000 samples
% verbose: Inform whether a sub-network collapsed
%
% OUTPUT
% CoO: Variable encoding if a sub-network collapsed
% allphi: All phases versus oscillator index and time, Eqs. (1)-(2)
% ResDeltaC: Eq. (14)
% ResXi: Eq. (16), but in this source code for system Y.
% ResS: Eq. (9)
% ResK: Correlation coefficient between order parameter amplitudes
% ResDPhi: Eq. (10)
% ResLW, Eq. (11)
% ResLS, Eq. (12)
% ResG: Generalized synchronization G.



% Initialize random number generator
rng('shuffle');
% Linking function of differential equation (at end of this script).
deriv = @AndrzejakEspinosoNetworkDifferentialEquation;

% Setting index ranges for the
% driver, response, and auxiliary response
idriver = 1:N;
iresponse = N+1:2*N;
iaresponse = 2*N+1:3*N;
% Creating a matrix with the alpha paramter values
alphaV = zeros(3*N);
alphaV(idriver,idriver) = alphaX;
alphaV(iresponse,iresponse) = alphaY;
alphaV(iaresponse,iaresponse) = alphaY;
% Creating a vector with the omega paramter values
nu=zeros(3*N,1);
nu(idriver) = nuX;
nu(iresponse) = nuY;
nu(iaresponse) = nuY;

% Initialzing coupling matrix at first only with within layer couplings
A = zeros(3*N,3*N);
Rectangularwindow = zeros(N,1);
Rectangularwindow(1:bX+1)=1;
Rectangularwindow(N-bX+1:N)=1;
for i = idriver
    A(i,idriver)=circshift(Rectangularwindow,i-1);
end
A(idriver,idriver) = A(idriver,idriver)/2/bX;
Rectangularwindow = zeros(N,1);
Rectangularwindow(1:bY+1)=1;
Rectangularwindow(N-bY+1:N)=1;
for i = iresponse
    A(i,iresponse)=circshift(Rectangularwindow,i-1);
end
A(iresponse,iresponse) = A(iresponse,iresponse)/2/bY;
for i = iaresponse
    A(i,iaresponse)=circshift(Rectangularwindow,i-1);
end
A(iaresponse,iaresponse) = A(iaresponse,iaresponse)/2/bY;



cc = 0; % counting variable
% Allocate some of the result variables
ResultDeltaC_of_t = zeros(round((TS-EO)/T),1); % Eq. 13
ResultXi_y_of_t = zeros(round((TS-EO)/T),1); % Eq. 15

% Allocate variables for all phases
allphi = zeros(TS,N*3);
% Initializing with random phases
phi = rand(3*N,1)*2*pi;

% Allocate variables for complex order parameters for the three sub-networks
% driver, response, and auxiliary response 
ZX_of_t = zeros(TS,1);
ZY_of_t = zeros(TS,1);
ZYA_of_t = zeros(TS,1);

% Setting default outcome. Will be overwritten in case a sub-network
% collapses
CoO = 0;

% Loop from 1 to total number of samples
for j =1:TS
    if j==CO;
        % Adding inter-layer coupling to matrix (done only once).
        for i = 1:N
            A(i+N,i)=epsilon;
            A(i+2*N,i)=epsilon;
        end
    end
    % Runge-Kutta step
    k1 = Deltat*feval(deriv,phi,A,alphaV,nu);
    k2 = Deltat*feval(deriv,phi+k1/2,A,alphaV,nu);
    k3 = Deltat*feval(deriv,phi+k2/2,A,alphaV,nu);
    k4 = Deltat*feval(deriv,phi+k3,A,alphaV,nu);
    phi = phi + k1/6+k2/3+k3/3+k4/6;
    
    phi = mod(phi,2*pi);
    allphi(j,:)=phi;
    if j > EO
        if (mod(j,T)==0) % Eq. (5) and resulting quantities are evaluated only every T samples.
            cc =cc+1;
            theta_xj_of_t=std(diff(unwrap(allphi(j-T+1:j,idriver))));
            C_x_of_t = (N/2/pi)*(angle(mean((theta_xj_of_t).*exp(1i*(((1:N)*2*pi)-pi*N)/N)))+pi);
            thetayj_of_t=std(diff(unwrap(allphi(j-T+1:j,iresponse))));
            C_y_of_t = (N/2/pi)*(angle(mean((thetayj_of_t).*exp(1i*(((1:N)*2*pi)-pi*N)/N)))+pi);
            temp = abs(C_y_of_t-C_x_of_t);
            ResultDeltaC_of_t(cc) = min(temp,N-temp)/(N/4);
            ResultXi_y_of_t(cc) = std(thetayj_of_t)/mean(thetayj_of_t);
        end
    end
    
    % Determine complex order parameters for the three sub-networks
    % driver, response, and auxiliary response
    ZX_of_t(j) = 1/N*(sum(exp(1i*phi(idriver))));
    ZY_of_t(j) = 1/N*(sum(exp(1i*phi(iresponse))));
    ZYA_of_t(j) = 1/N*(sum(exp(1i*phi(iaresponse))));
    
    % Check if some sub-network has collapsed to fully synchronized state
    if abs(ZX_of_t(j)) >0.9999
        CoO=1;
        if verbose
            disp('Driver collapsed.');
        end
        break
    end
    
    if ((abs(ZY_of_t(j)) >0.9999) && (A(3*N,N)==0))
        CoO=2;
        if verbose
            disp('Response collapsed prior to coupling onset.');
        end
        
        break
    end
    if ((abs(ZYA_of_t(j)) >0.9999) && (A(3*N,N)==0))
        CoO=3;
        if verbose
            disp('Auxiliary response collapsed prior to coupling onset.');
        end
        break
    end
end

% Extraction of all result variables
% If one of the networks collapsed, the results are invalid. They are all
% set to empty values. If this happens, you should start a new realization
% with new random initial conditions.
if CoO == 0
    delta_response_aresponse=abs(sin((allphi(EO+1:TS,iresponse)-allphi(EO+1:TS,iaresponse))/2));
    temp = min(min(delta_response_aresponse));
    if temp < 1e-13
        ResG = 1;
    else
        ResG = 0;
    end
    clear delta_response_aresponse
    
    aZX = angle(ZX_of_t(EO+1:TS));
    aZY = angle(ZY_of_t(EO+1:TS));
    uaZX = unwrap(aZX);
    uaZY = unwrap(aZY);
    Delta_phi_j = uaZX-uaZY;
    ResS=(max(Delta_phi_j)-min(Delta_phi_j))/(2*pi);
    if ResS<1
        ResDPhi = angle(mean(exp(1i*(aZX-aZY))));
    else
        ResDPhi=[];
    end
    clear aZX
    clear aZY
    clear uaZX
    clear uaZY
    
    
    ResDeltaC=mean(ResultDeltaC_of_t);
    ResXi=mean(ResultXi_y_of_t);
    
    lZX = abs(ZX_of_t(EO+1:TS));
    lZY = abs(ZY_of_t(EO+1:TS));
    mycorr = corrcoef(lZX,lZY);
    ResK = mycorr(1,2);
    clear lZX
    clear lZY
    
    s_j=zeros(1,N);
    for j = 1:N
        Delta_phi_j=unwrap(allphi(EO+1:TS,j))-unwrap(allphi(EO+1:TS,j+N));
        s_j(j) = (max(Delta_phi_j)-min(Delta_phi_j))/(2*pi);
    end
    ResLS = length(find((s_j<1e-10)))/N; 
    % In principle, strong phase locking requires s_j==0. However, there 
    % remains always some numerical noise. The arbitrary but small threshold 
    % of s_j<1e-10 was set empirically to detect strong phase locking.
    ResLW = length(find((s_j<1)))/N-ResLS;
else
    ResDeltaC = [];
    ResXi =[];
    ResS=[];
    ResK=[];
    ResLS=[];
    ResLW=[];
    ResDPhi=[];
    ResG=[];
end

function dphi = AndrzejakEspinosoNetworkDifferentialEquation(phi,G,alpha,omega)
diffm=bsxfun(@minus,phi,phi');
dphi = omega-sum(sin(diffm+alpha).*G,2);




